@@ -360,8 +360,8 @@ class Fresnel(Graph):
                 log.debug("    Type: %s" % typ)
                 resources = list(graph.triples((resource, RDF["type"], typ)))
                 resources.sort(lambda x,y: cmp(x[0], y[0]))
-                for resource, _p, _o in resources:
-                    styles, element = lens.formatResource(graph, resource)
+                for s, _p, _o in resources:
+                    styles, element = lens.formatResource(graph, s)
                     [stylesheets.add(x) for x in styles]
                     root.append(element)
 
@@ -392,7 +392,7 @@ class Render(Command):
         tmp = self.handler.get(fresnel_uri)
         fresnel = Fresnel(store=tmp.store, identifier=tmp.identifier)
         graph = self.handler.get(graph_uri)
-        stylesheets, tree = fresnel.format(graph, URIRef(self.options.resource))
+        stylesheets, tree = fresnel.format(graph, URIRef(self.options.resource) if self.options.resource else None)
 
         head = template.find("head")
         if head is None:
